#
# Conditional build:
%bcond_without	apidocs		# API documentation (doxygen based)
%bcond_without	openmpt123	# openmpt123 CLI player
%bcond_without	portaudio	# PortAudio support
%bcond_with	sdl		# SDL2 output in openmpt123
%bcond_without	static_libs	# static library
%bcond_without	tests		# unit tests
#
Summary:	Tracker module player based on OpenMPT
Summary(pl.UTF-8):	Odtwarzacz modułów ścieżkowych oparty na OpenMPT
Name:		libopenmpt
Version:	0.7.13
Release:	1
License:	BSD
Group:		Libraries
Source0:	https://lib.openmpt.org/files/libopenmpt/src/%{name}-%{version}+release.autotools.tar.gz
# Source0-md5:	8e8ff375a24a8171924af7c5431b9182
URL:		https://lib.openmpt.org/
%{?with_apidocs:BuildRequires:	doxygen}
BuildRequires:	libmpg123-devel >= 1.14.0
BuildRequires:	libogg-devel
# C++17 mandatory, C++20 optional
BuildRequires:	libstdc++-devel >= 6:7
BuildRequires:	libvorbis-devel
BuildRequires:	pkgconfig >= 1:0.24
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 1.752
BuildRequires:	zlib-devel
%if %{with openmpt123}
%{?with_sdl:BuildRequires:	SDL2-devel >= 2.0.4}
BuildRequires:	flac-devel >= 1.3.0
BuildRequires:	libsndfile-devel
%if %{with portaudio}
BuildRequires:	portaudio-devel >= 19
BuildRequires:	portaudio-c++-devel >= 19
%endif
BuildRequires:	pulseaudio-devel
%endif
Requires:	libmpg123 >= 1.14.0
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Tracker module player based on OpenMPT.

%description -l pl.UTF-8
Odtwarzacz modułów ścieżkowych oparty na OpenMPT.

%package devel
Summary:	Header files for OpenMPT library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki OpenMPT
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	libmpg123-devel
Requires:	libogg-devel
Requires:	libvorbis-devel
Requires:	zlib-devel

%description devel
Header files for OpenMPT library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki OpenMPT.

%package static
Summary:	Static OpenMPT library
Summary(pl.UTF-8):	Statyczna biblioteka OpenMPT
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static OpenMPT library.

%description static -l pl.UTF-8
Statyczna biblioteka OpenMPT.

%package apidocs
Summary:	API documentation for OpenMPT library
Summary(pl.UTF-8):	Dokumentacja API biblioteki OpenMPT
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation and examples for OpenMPT library.

%description apidocs -l pl.UTF-8
Dokumentacja API i przykłady do biblioteki OpenMPT.

%package -n openmpt123
Summary:	Command line module music player based on libopenmpt
Summary(pl.UTF-8):	Działający z linii poleceń odtwarzacz modułów muzycznych oparty na libopenmpt
Group:		Applications/Sound
Requires:	%{name} = %{version}-%{release}
Requires:	flac >= 1.3.0

%description -n openmpt123
Command line module music player based on libopenmpt.

%description -n openmpt123 -l pl.UTF-8
Działający z linii poleceń odtwarzacz modułów muzycznych oparty na
libopenmpt.

%prep
%setup -q -n %{name}-%{version}+release.autotools

%build
%configure \
	--disable-examples \
	%{!?with_openmpt123:--disable-openmpt123} \
	%{!?with_static_libs:--disable-static} \
	%{!?with_portaudio:--without-portaudio} \
	%{!?with_portaudio:--without-portaudiocpp} \
	%{?with_sdl:--with-sdl2}
%{__make}

%if %{with tests}
%{__make} check
%endif

%if %{with apidocs}
doxygen
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%if %{with apidocs}
install -d $RPM_BUILD_ROOT%{_examplesdir}
%{__mv} $RPM_BUILD_ROOT%{_docdir}/%{name}/examples $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
%endif
# packaged as %doc / examples
%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/%{name}
# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libopenmpt.la

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
# don't package README.md here, it contains only packager and libopenmpt developer information
%doc LICENSE
%attr(755,root,root) %{_libdir}/libopenmpt.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libopenmpt.so.0

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libopenmpt.so
%{_includedir}/libopenmpt
%{_pkgconfigdir}/libopenmpt.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libopenmpt.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%doc doxygen-doc/html/*
%{_examplesdir}/%{name}-%{version}
%endif

%if %{with openmpt123}
%files -n openmpt123
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/openmpt123
%{_mandir}/man1/openmpt123.1*
%endif
%changelog
* Wed Mar 19 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libopenmpt.git;a=log;h=master

* Wed Mar 19 2025 Jakub Bogusz <qboosh@pld-linux.org> 700af79
- updated to 0.7.13

* Fri Feb 14 2025 Jan Palus <atler@pld-linux.org> 69a40c7
- flac 1.5.0 rebuild

* Mon Nov 11 2024 Jakub Bogusz <qboosh@pld-linux.org> b396606
- updated to 0.7.11

* Wed Sep 25 2024 Jakub Bogusz <qboosh@pld-linux.org> 47ee7a7
- updated to 0.7.10

* Tue Sep 03 2024 Jakub Bogusz <qboosh@pld-linux.org> 567458b
- updated to 0.7.9

* Sun Jun 16 2024 Jakub Bogusz <qboosh@pld-linux.org> c6c95c6
- updated to 0.7.8

* Sun May 26 2024 Jakub Bogusz <qboosh@pld-linux.org> ebeaa82
- updated to 0.7.7

* Wed Mar 27 2024 Jakub Bogusz <qboosh@pld-linux.org> 9415bfe
- updated to 0.7.6 (security fixes)

* Tue Mar 05 2024 Jakub Bogusz <qboosh@pld-linux.org> 1a784de
- updated to 0.7.4

* Sun Oct 22 2023 Jakub Bogusz <qboosh@pld-linux.org> de6ecf3
- updated to 0.7.3

* Mon Jun 26 2023 Jakub Bogusz <qboosh@pld-linux.org> bbf8cfe
- updated to 0.7.2

* Sat Apr 01 2023 Jakub Bogusz <qboosh@pld-linux.org> 6e5efc6
- updated to 0.6.9

* Wed Feb 22 2023 Jan Palus <atler@pld-linux.org> bcc2661
- add portaudio bcond

* Sun Sep 11 2022 Jan Palus <atler@pld-linux.org> f575f92
- flac rebuild

* Fri Apr 01 2022 Jakub Bogusz <qboosh@pld-linux.org> 166002a
- updated to 0.6.2

* Wed Oct 27 2021 Jan Palus <atler@pld-linux.org> 17e0500
- don't build examples

* Sun Apr 25 2021 Jakub Bogusz <qboosh@pld-linux.org> 08b3cc3
- updated to 0.5.8

* Sun Mar 07 2021 Jan Rękorajski <baggins@pld-linux.org> ce57157
- unconditional noarch subpackages

* Sun Jan 10 2021 Jakub Bogusz <qboosh@pld-linux.org> b2eb5c9
- updated to 0.5.4

* Tue Jul 07 2020 Jakub Bogusz <qboosh@pld-linux.org> 765c944
- updated to 0.5.0; C++17 now

